@@ -41,6 +41,8 @@
 
 #include "cvtest.h"
 
+#if 0
+
 #include "aeigenobjects.inc"
 
 #define __8U   8
@@ -68,7 +70,7 @@ static double rel_bufSize;
 
 /*-----------------------------=--=-=== Callback functions ===-=--=---------------------*/
 
-CvStatus read_callback_8u( int ind, void* buf, void* userData)
+int read_callback_8u( int ind, void* buf, void* userData)
 {
     int i, j, k = 0;
     UserData* data = (UserData*)userData;
@@ -76,7 +78,7 @@ CvStatus read_callback_8u( int ind, void* buf, void* userData)
     uchar* buff = (uchar*)buf;
 
     if( ind<0 ) return CV_BADFACTOR_ERR;
-    if( buf==NULL || userData==NULL ) CV_NULLPTR_ERR;
+    if( buf==NULL || userData==NULL ) return CV_NULLPTR_ERR;
 
     for( i=0; i<data->size1.height; i++, start+=data->step1 )
         for( j=0; j<data->size1.width; j++, k++ )
@@ -84,7 +86,7 @@ CvStatus read_callback_8u( int ind, void* buf, void* userData)
     return CV_NO_ERR;
 }
 /*----------------------*/
-CvStatus read_callback_32f( int ind, void* buf, void* userData)
+int read_callback_32f( int ind, void* buf, void* userData)
 {
     int i, j, k = 0;
     UserData* data = (UserData*)userData;
@@ -92,7 +94,7 @@ CvStatus read_callback_32f( int ind, void* buf, void* userData)
     float* buff = (float*)buf;
 
     if( ind<0 ) return CV_BADFACTOR_ERR;
-    if( buf==NULL || userData==NULL ) CV_NULLPTR_ERR;
+    if( buf==NULL || userData==NULL ) return CV_NULLPTR_ERR;
 
     for( i=0; i<data->size2.height; i++, start+=data->step2/4 )
         for( j=0; j<data->size2.width; j++, k++ )
@@ -100,7 +102,7 @@ CvStatus read_callback_32f( int ind, void* buf, void* userData)
     return CV_NO_ERR;
 }
 /*========================*/
-CvStatus write_callback_8u( int ind, void* buf, void* userData)
+int write_callback_8u( int ind, void* buf, void* userData)
 {
     int i, j, k = 0;
     UserData* data = (UserData*)userData;
@@ -108,7 +110,7 @@ CvStatus write_callback_8u( int ind, void* buf, void* userData)
     uchar* buff = (uchar*)buf;
 
     if( ind<0 ) return CV_BADFACTOR_ERR;
-    if( buf==NULL || userData==NULL ) CV_NULLPTR_ERR;
+    if( buf==NULL || userData==NULL ) return CV_NULLPTR_ERR;
 
     for( i=0; i<data->size1.height; i++, start+=data->step1 )
         for( j=0; j<data->size1.width; j++, k++ )
@@ -116,7 +118,7 @@ CvStatus write_callback_8u( int ind, void* buf, void* userData)
     return CV_NO_ERR;
 }
 /*----------------------*/
-CvStatus write_callback_32f( int ind, void* buf, void* userData)
+int write_callback_32f( int ind, void* buf, void* userData)
 {
     int i, j, k = 0;
     UserData* data = (UserData*)userData;
@@ -124,7 +126,7 @@ CvStatus write_callback_32f( int ind, void* buf, void* userData)
     float* buff = (float*)buf;
 
     if( ind<0 ) return CV_BADFACTOR_ERR;
-    if( buf==NULL || userData==NULL ) CV_NULLPTR_ERR;
+    if( buf==NULL || userData==NULL ) return CV_NULLPTR_ERR;
 
     for( i=0; i<data->size2.height; i++, start+=data->step2/4 )
         for( j=0; j<data->size2.width; j++, k++ )
@@ -147,14 +149,14 @@ static int fmaEigenObjects( void )
     double eps0, amax=0, singleCoeff, p;
     AtsRandState state;
     CvSize size;
-    CvStatus  r;
+    int  r;
     CvTermCriteria limit;
     UserData userData;
-    CvStatus (*read_callback)( int ind, void* buf, void* userData)=
+    int (*read_callback)( int ind, void* buf, void* userData)=
                  read_callback_8u;
-    CvStatus (*read2_callback)( int ind, void* buf, void* userData)=
+    int (*read2_callback)( int ind, void* buf, void* userData)=
                  read_callback_32f;
-    CvStatus (*write_callback)( int ind, void* buf, void* userData)=
+    int (*write_callback)( int ind, void* buf, void* userData)=
                  write_callback_32f;
     CvInput* u_r = (CvInput*)&read_callback;
     CvInput* u_r2= (CvInput*)&read2_callback;
@@ -175,19 +177,19 @@ static int fmaEigenObjects( void )
     n = obj_width * obj_height;
     sizex = obj_width,  sizey = obj_height;
 
-    Objs     = (IplImage**)icvAlloc(sizeof(IplImage*) * obj_number );
-    EigObjs  = (IplImage**)icvAlloc(sizeof(IplImage*) * m1         );
-    EigObjs0 = (IplImage**)icvAlloc(sizeof(IplImage*) * m1         );
+    Objs     = (IplImage**)cvAlloc(sizeof(IplImage*) * obj_number );
+    EigObjs  = (IplImage**)cvAlloc(sizeof(IplImage*) * m1         );
+    EigObjs0 = (IplImage**)cvAlloc(sizeof(IplImage*) * m1         );
 
-    objs     = (uchar**)icvAlloc(sizeof(uchar*) * obj_number     );
-    eigObjs  = (float**)icvAlloc(sizeof(float*) * m1             );
-    eigObjs0 = (float**)icvAlloc(sizeof(float*) * m1             );
-    covMatr  = (float*) icvAlloc(sizeof(float)  * obj_number * obj_number );
-    covMatr0 = (float*) icvAlloc(sizeof(float)  * obj_number * obj_number );
-    coeffs   = (float*) icvAlloc(sizeof(float*) * m1             );
-    coeffs0  = (float*) icvAlloc(sizeof(float*) * m1             );
-    eigVal   = (float*) icvAlloc(sizeof(float)  * obj_number     );
-    eigVal0  = (float*) icvAlloc(sizeof(float)  * obj_number     );
+    objs     = (uchar**)cvAlloc(sizeof(uchar*) * obj_number     );
+    eigObjs  = (float**)cvAlloc(sizeof(float*) * m1             );
+    eigObjs0 = (float**)cvAlloc(sizeof(float*) * m1             );
+    covMatr  = (float*) cvAlloc(sizeof(float)  * obj_number * obj_number );
+    covMatr0 = (float*) cvAlloc(sizeof(float)  * obj_number * obj_number );
+    coeffs   = (float*) cvAlloc(sizeof(float*) * m1             );
+    coeffs0  = (float*) cvAlloc(sizeof(float*) * m1             );
+    eigVal   = (float*) cvAlloc(sizeof(float)  * obj_number     );
+    eigVal0  = (float*) cvAlloc(sizeof(float)  * obj_number     );
 
     size.width = obj_width;  size.height = obj_height;
     atsRandInit( &state, 0, 255, 13 );
@@ -227,7 +229,7 @@ static int fmaEigenObjects( void )
         }
     }
 
-    limit.type = CV_TERMCRIT_ITER;  limit.maxIter = m1;  limit.epsilon = 1;//(float)eps0;
+    limit.type = CV_TERMCRIT_ITER;  limit.max_iter = m1;  limit.epsilon = 1;//(float)eps0;
 
     bufSize = (int)(4*n*obj_number*rel_bufSize);
 trsWrite(TW_RUN|TW_CON, "\n i/o buffer size : %10d bytes\n", bufSize );
@@ -363,7 +365,7 @@ repeat:
 
 /*  Covariance matrix comparision */
     for( i=0; i<obj_number*obj_number; i++ )
-        if( fabs( (covMatr[i] - covMatr0[i])/covMatrMax ) > RELDIFF ) err6++;
+        if( fabs(covMatr[i] - covMatr0[i]) > RELDIFF*fabs(covMatrMax) ) err6++;
 
 /*  Averaged object comparision */
     for( i=0; i<size.height; i++ )
@@ -737,18 +739,18 @@ trsWrite(TW_RUN|TW_CON, "\n ROI   supported\n" );
         }
     }
 
-    icvFree( (void**)&objs     );
-    icvFree( (void**)&eigObjs  );
-    icvFree( (void**)&eigObjs0 );
-    icvFree( (void**)&coeffs   );
-    icvFree( (void**)&coeffs0  );
-    icvFree( (void**)&eigVal   );
-    icvFree( (void**)&eigVal0  );
-    icvFree( (void**)&Objs     );
-    icvFree( (void**)&EigObjs  );
-    icvFree( (void**)&EigObjs0 );
-    icvFree( (void**)&covMatr  );
-    icvFree( (void**)&covMatr0 );
+    cvFree( &objs     );
+    cvFree( &eigObjs  );
+    cvFree( &eigObjs0 );
+    cvFree( &coeffs   );
+    cvFree( &coeffs0  );
+    cvFree( &eigVal   );
+    cvFree( &eigVal0  );
+    cvFree( &Objs     );
+    cvFree( &EigObjs  );
+    cvFree( &EigObjs0 );
+    cvFree( &covMatr  );
+    cvFree( &covMatr0 );
 
 trsWrite(TW_RUN|TW_CON, "\n Errors number: %d\n", err );
 
@@ -764,4 +766,6 @@ void InitAEigenObjects( void )
     trsReg( FuncName, TestName, TestClass, fmaEigenObjects );
 } /* InitAEigenObjects */
 
+#endif
+
 /*  End of file  */
